"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSDK = void 0;
/**
 * Thanks to @cookpete
 * https://github.com/cookpete/react-player/blob/master/src/utils.js
 */
var load_script_1 = require("load-script");
function getGlobal(key) {
    if (window[key]) {
        return window[key];
    }
    if (window.exports && window.exports[key]) {
        return window.exports[key];
    }
    if (window.module && window.module.exports && window.module.exports[key]) {
        return window.module.exports[key];
    }
    return null;
}
var requests = {};
function getSDK(url, sdkGlobal, sdkReady, isLoaded, fetchScript) {
    if (sdkReady === void 0) { sdkReady = null; }
    if (isLoaded === void 0) { isLoaded = function () { return true; }; }
    if (fetchScript === void 0) { fetchScript = load_script_1.default; }
    var existingGlobal = getGlobal(sdkGlobal);
    if (existingGlobal && isLoaded(existingGlobal)) {
        return Promise.resolve(existingGlobal);
    }
    return new Promise(function (resolve, reject) {
        // If we are already loading the SDK, add the resolve and reject
        // functions to the existing array of requests
        if (requests[url]) {
            requests[url].push({ resolve: resolve, reject: reject });
            return;
        }
        requests[url] = [{ resolve: resolve, reject: reject }];
        var onLoaded = function (sdk) {
            // When loaded, resolve all pending request promises
            requests[url].forEach(function (request) { return request.resolve(sdk); });
        };
        if (sdkReady) {
            var previousOnReady_1 = window[sdkReady];
            window[sdkReady] = function () {
                if (previousOnReady_1)
                    previousOnReady_1();
                onLoaded(getGlobal(sdkGlobal));
            };
        }
        fetchScript(url, function (err) {
            if (err) {
                // Loading the SDK failed – reject all requests and
                // reset the array of requests for this SDK
                requests[url].forEach(function (request) { return request.reject(err); });
                requests[url] = null;
            }
            else if (!sdkReady) {
                onLoaded(getGlobal(sdkGlobal));
            }
        });
    });
}
exports.getSDK = getSDK;
